@@ -4,7 +4,6 @@ import (
 	"fmt"
 	"regexp"
 	"runtime/debug"
-	"strings"
 	"time"
 
 	"github.com/alecthomas/chroma/v2"
@@ -90,10 +89,6 @@ type Pager struct {
 	// clear the last line, and show the cursor.
 	DeInit bool
 
-	// Optional ANSI to prefix each text line with. Initialised using
-	// ChromaStyle and ChromaFormatter. Used for coloring unstyled text lines
-	// based on the Chroma style.
-	linePrefix     string
 	WithTerminalFg bool // If true, don't set linePrefix
 
 	// Length of the longest line displayed. This is used for limiting scrolling to the right.
@@ -114,8 +109,6 @@ type _PreHelpState struct {
 	targetLineNumber    *linenumbers.LineNumber
 }
 
-const _EofMarkerFormat = "\x1b[7m" // Reverse video
-
 var _HelpReader = NewReaderFromText("Help", `
 Welcome to Moar, the nice pager!
 
@@ -141,14 +134,14 @@ Moving around
 * SPACE moves down a page
 * < / 'gg' to go to the start of the document
 * > / 'G' to go to the end of the document
-* 'h', 'l' for left and right (as in vim)
 * Half page 'u'p / 'd'own, or CTRL-u / CTRL-d
 * RETURN moves down one line
 
 Searching
 ---------
 * Type / to start searching, then type what you want to find
-* Type RETURN to stop searching
+* Type ? to search backwards, then type what you want to find
+* Type RETURN to stop searching, or ESC to skip back to where the search started
 * Find next by typing 'n' (for "next")
 * Find previous by typing SHIFT-N or 'p' (for "previous")
 * Search is case sensitive if it contains any UPPER CASE CHARACTERS
@@ -275,37 +268,9 @@ func (p *Pager) handleScrolledDown() {
 	}
 }
 
-// Return an ANSI SGR sequence to use for plain text. Can be "".
-func getLineColorPrefix(chromaStyle *chroma.Style, chromaFormatter *chroma.Formatter) string {
-	if chromaStyle == nil && chromaFormatter == nil {
-		return ""
-	}
-	if chromaStyle == nil || chromaFormatter == nil {
-		panic("Both ChromaStyle and ChromaFormatter should be set or neither")
-	}
-
-	stringBuilder := strings.Builder{}
-	err := (*chromaFormatter).Format(&stringBuilder, chromaStyle, chroma.Literator(chroma.Token{
-		Type:  chroma.None,
-		Value: "XXX",
-	}))
-	if err != nil {
-		panic(err)
-	}
-
-	formatted := stringBuilder.String()
-	cutoff := strings.Index(formatted, "XXX")
-	if cutoff < 0 {
-		panic("XXX not found in " + formatted)
-	}
-
-	return formatted[:cutoff]
-}
-
 // StartPaging brings up the pager on screen
 func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chromaFormatter *chroma.Formatter) {
-	log.Trace("Pager starting")
-	defer log.Trace("Pager done")
+	log.Info("Pager starting")
 
 	defer func() {
 		if p.reader.err != nil {
@@ -315,13 +280,9 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 
 	textstyles.UnprintableStyle = p.UnprintableStyle
 	consumeLessTermcapEnvs(chromaStyle, chromaFormatter)
-	styleUI(chromaStyle, chromaFormatter, p.StatusBarStyle)
+	styleUI(chromaStyle, chromaFormatter, p.StatusBarStyle, p.WithTerminalFg)
 
 	p.screen = screen
-	if !p.WithTerminalFg {
-		// Use the plain text color from the theme
-		p.linePrefix = getLineColorPrefix(chromaStyle, chromaFormatter)
-	}
 	p.mode = PagerModeViewing{pager: p}
 	p.marks = make(map[rune]scrollPosition)
 
@@ -352,11 +313,7 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 		// Spin the spinner as long as contents is still loading
 		spinnerFrames := [...]string{"/.\\", "-o-", "\\O/", "| |"}
 		spinnerIndex := 0
-		for {
-			if p.reader.done.Load() {
-				break
-			}
-
+		for !p.reader.done.Load() {
 			screen.Events() <- eventSpinnerUpdate{spinnerFrames[spinnerIndex]}
 			spinnerIndex++
 			if spinnerIndex >= len(spinnerFrames) {
@@ -380,6 +337,8 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 		}
 	}()
 
+	log.Info("Entering pager main loop...")
+
 	// Main loop
 	spinner := ""
 	for !p.quit {
@@ -402,6 +361,8 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 					// Without this the line numbers setting ^ won't take effect
 					p.redraw(spinner)
 
+					log.Info("Exiting because of --quit-if-one-screen, we fit on one screen and we're done")
+
 					break
 				}
 			}
@@ -439,7 +400,7 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 			// We'll be implicitly redrawn just by taking another lap in the loop
 
 		case twin.EventExit:
-			log.Debug("Got a Twin exit event, exiting")
+			log.Info("Got a Twin exit event, exiting")
 			return
 
 		case eventMoreLinesAvailable:
