@@ -127,18 +127,18 @@ func getTestFiles(t *testing.T) []string {
 }
 
 // Wait for reader to finish reading and highlighting. Used by tests.
-func (r *Reader) _wait() error {
+func (reader *Reader) _wait() error {
 	// Wait for our goroutine to finish
 	//revive:disable-next-line:empty-block
-	for !r.done.Load() {
+	for !reader.done.Load() {
 	}
 	//revive:disable-next-line:empty-block
-	for !r.highlightingDone.Load() {
+	for !reader.highlightingDone.Load() {
 	}
 
-	r.Lock()
-	defer r.Unlock()
-	return r.err
+	reader.Lock()
+	defer reader.Unlock()
+	return reader.err
 }
 
 func TestGetLines(t *testing.T) {
@@ -303,15 +303,17 @@ func TestReadFileDoneYesHighlighting(t *testing.T) {
 }
 
 func TestReadStreamDoneNoHighlighting(t *testing.T) {
-	testMe := NewReaderFromStream("", strings.NewReader("Johan"), nil, ReaderOptions{Style: &chroma.Style{}})
+	testMe, err := NewReaderFromStream("", strings.NewReader("Johan"), nil, ReaderOptions{Style: &chroma.Style{}})
+	assert.NilError(t, err)
 
 	assert.NilError(t, testMe._wait())
 }
 
 func TestReadStreamDoneYesHighlighting(t *testing.T) {
-	testMe := NewReaderFromStream("",
+	testMe, err := NewReaderFromStream("",
 		strings.NewReader("Johan"),
 		formatters.TTY, ReaderOptions{Lexer: lexers.EmacsLisp, Style: styles.Get("native")})
+	assert.NilError(t, err)
 
 	assert.NilError(t, testMe._wait())
 }
@@ -325,7 +327,7 @@ func TestReadTextDone(t *testing.T) {
 // JSON should be auto detected and formatted
 func TestFormatJson(t *testing.T) {
 	jsonStream := strings.NewReader(`{"key": "value"}`)
-	testMe := NewReaderFromStream(
+	testMe, err := NewReaderFromStream(
 		"JSON test",
 		jsonStream,
 		formatters.TTY,
@@ -333,6 +335,7 @@ func TestFormatJson(t *testing.T) {
 			Style:        styles.Get("native"),
 			ShouldFormat: true,
 		})
+	assert.NilError(t, err)
 
 	assert.NilError(t, testMe._wait())
 
@@ -343,13 +346,36 @@ func TestFormatJson(t *testing.T) {
 	assert.Equal(t, len(lines.lines), 3)
 }
 
+func TestFormatJsonArray(t *testing.T) {
+	jsonStream := strings.NewReader(`[{"key": "value"}]`)
+	testMe, err := NewReaderFromStream(
+		"JSON test",
+		jsonStream,
+		formatters.TTY,
+		ReaderOptions{
+			Style:        styles.Get("native"),
+			ShouldFormat: true,
+		})
+	assert.NilError(t, err)
+
+	assert.NilError(t, testMe._wait())
+
+	lines, _ := testMe.GetLines(linenumbers.LineNumber{}, 10)
+	assert.Equal(t, lines.lines[0].Plain(nil), "[")
+	assert.Equal(t, lines.lines[1].Plain(nil), "  {")
+	assert.Equal(t, lines.lines[2].Plain(nil), `    "key": "value"`)
+	assert.Equal(t, lines.lines[3].Plain(nil), "  }")
+	assert.Equal(t, lines.lines[4].Plain(nil), "]")
+	assert.Equal(t, len(lines.lines), 5)
+}
+
 // If people keep appending to the currently opened file we should display those
 // changes.
 func TestReadUpdatingFile(t *testing.T) {
 	// Make a temp file containing one line of text, ending with a newline
 	file, err := os.CreateTemp("", "moar-TestReadUpdatingFile-*.txt")
 	assert.NilError(t, err)
-	defer os.Remove(file.Name())
+	defer os.Remove(file.Name()) //nolint:errcheck
 
 	const firstLineString = "First line\n"
 	_, err = file.WriteString(firstLineString)
@@ -426,7 +452,7 @@ func TestReadUpdatingFile_InitiallyEmpty(t *testing.T) {
 	// Make a temp file containing one line of text, ending with a newline
 	file, err := os.CreateTemp("", "moar-TestReadUpdatingFile_NoNewlineAtEOF-*.txt")
 	assert.NilError(t, err)
-	defer os.Remove(file.Name())
+	defer os.Remove(file.Name()) //nolint:errcheck
 
 	// Start a reader on that file
 	testMe, err := NewReaderFromFilename(file.Name(), formatters.TTY16m, ReaderOptions{Style: styles.Get("native")})
@@ -468,7 +494,7 @@ func TestReadUpdatingFile_HalfLine(t *testing.T) {
 	// Make a temp file containing one line of text, ending with a newline
 	file, err := os.CreateTemp("", "moar-TestReadUpdatingFile-*.txt")
 	assert.NilError(t, err)
-	defer os.Remove(file.Name())
+	defer os.Remove(file.Name()) //nolint:errcheck
 
 	_, err = file.WriteString("Start")
 	assert.NilError(t, err)
@@ -512,7 +538,7 @@ func TestReadUpdatingFile_HalfUtf8(t *testing.T) {
 	// Make a temp file containing one line of text, ending with a newline
 	file, err := os.CreateTemp("", "moar-TestReadUpdatingFile-*.txt")
 	assert.NilError(t, err)
-	defer os.Remove(file.Name())
+	defer os.Remove(file.Name()) //nolint:errcheck
 
 	// Write "h" and half an "ä" to the file
 	_, err = file.Write([]byte("här"[0:2]))
