@@ -11,14 +11,14 @@ import (
 	"gotest.tools/v3/assert"
 )
 
-//revive:disable:empty-block
+// NOTE: You can find related tests in pager_test.go.
 
-func testHorizontalCropping(t *testing.T, contents string, firstIndex int, lastIndex int, expected string, expectedOverflow overflowState) {
+func testHorizontalCropping(t *testing.T, contents string, firstVisibleColumn int, lastVisibleColumn int, expected string, expectedOverflow overflowState) {
 	pager := NewPager(nil)
 	pager.ShowLineNumbers = false
 
-	pager.screen = twin.NewFakeScreen(1+lastIndex-firstIndex, 99)
-	pager.leftColumnZeroBased = firstIndex
+	pager.screen = twin.NewFakeScreen(1+lastVisibleColumn-firstVisibleColumn, 99)
+	pager.leftColumnZeroBased = firstVisibleColumn
 	pager.scrollPosition = newScrollPosition("testHorizontalCropping")
 
 	lineContents := NewLine(contents)
@@ -51,6 +51,26 @@ func TestCreateScreenLineCanAlmostScrollBoth(t *testing.T) {
 	testHorizontalCropping(t, "abcd", 1, 3, "<cd", didOverflow)
 }
 
+func TestCreateScreenLineChopWideCharLeft(t *testing.T) {
+	testHorizontalCropping(t, "上午下", 0, 10, "上午下", didFit)
+	testHorizontalCropping(t, "上午下", 1, 10, "<午下", didOverflow)
+	testHorizontalCropping(t, "上午下", 2, 10, "< 下", didOverflow)
+	testHorizontalCropping(t, "上午下", 3, 10, "<下", didOverflow)
+	testHorizontalCropping(t, "上午下", 4, 10, "<", didOverflow)
+	testHorizontalCropping(t, "上午下", 5, 10, "<", didOverflow)
+	testHorizontalCropping(t, "上午下", 6, 10, "<", didOverflow)
+	testHorizontalCropping(t, "上午下", 7, 10, "<", didOverflow)
+}
+
+func TestCreateScreenLineChopWideCharRight(t *testing.T) {
+	testHorizontalCropping(t, "上午下", 0, 6, "上午下", didFit)
+	testHorizontalCropping(t, "上午下", 0, 5, "上午下", didFit)
+	testHorizontalCropping(t, "上午下", 0, 4, "上午>", didOverflow)
+	testHorizontalCropping(t, "上午下", 0, 3, "上 >", didOverflow)
+	testHorizontalCropping(t, "上午下", 0, 2, "上>", didOverflow)
+	testHorizontalCropping(t, "上午下", 0, 1, " >", didOverflow)
+}
+
 func TestEmpty(t *testing.T) {
 	pager := Pager{
 		screen: twin.NewFakeScreen(99, 10),
@@ -83,7 +103,7 @@ func TestSearchHighlight(t *testing.T) {
 		{
 			inputLine: linenumbers.LineNumber{},
 			wrapIndex: 0,
-			cells: []twin.Cell{
+			cells: []twin.StyledRune{
 				{Rune: 'x', Style: twin.StyleDefault},
 				{Rune: '"', Style: twin.StyleDefault.WithAttr(twin.AttrReverse)},
 				{Rune: '"', Style: twin.StyleDefault.WithAttr(twin.AttrReverse)},
