@@ -211,7 +211,7 @@ func (screen *UnixScreen) Close() {
 		// * https://github.com/walles/moar/issues/145
 		// * https://github.com/walles/moar/issues/149
 		// * https://github.com/walles/moar/issues/150
-		log.Debug("Problem restoring TTY state: ", err)
+		log.Info("Problem restoring TTY state: ", err)
 	}
 }
 
@@ -220,8 +220,8 @@ func (screen *UnixScreen) Events() chan Event {
 }
 
 // Write string to ttyOut, panic on failure, return number of bytes written.
-func (screen *UnixScreen) write(string string) int {
-	bytesWritten, err := screen.ttyOut.Write([]byte(string))
+func (screen *UnixScreen) write(s string) int {
+	bytesWritten, err := screen.ttyOut.Write([]byte(s))
 	if err != nil {
 		panic(err)
 	}
@@ -246,6 +246,27 @@ func (screen *UnixScreen) hideCursor(hide bool) {
 	}
 }
 
+// Tell both screen.Size() and the client app that the window was resized
+func (screen *UnixScreen) onWindowResized() {
+	select {
+	case screen.sigwinch <- 0:
+		// Screen.Size() method notified about resize
+	default:
+		// Notification already pending, never mind
+	}
+
+	// Notify client app.
+	select {
+	case screen.events <- EventResize{}:
+		// Event delivered
+	default:
+		// This likely means that the user isn't processing events
+		// quickly enough. Maybe the user's queue will get flooded if
+		// the window is resized too quickly?
+		log.Warn("Unable to deliver EventResize, event queue full")
+	}
+}
+
 // Some terminals convert mouse events to key events making scrolling better
 // without our built-in mouse support, and some do not.
 //
@@ -267,41 +288,49 @@ func terminalHasArrowKeysEmulation() bool {
 
 	// Hyper, tested on macOS, December 14th 2023
 	if os.Getenv("TERM_PROGRAM") == "Hyper" {
+		log.Info("Hyper terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
 	// Kitty, tested on macOS, December 14th 2023
 	if os.Getenv("KITTY_WINDOW_ID") != "" {
+		log.Info("Kitty terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
 	// Alacritty, tested on macOS, December 14th 2023
 	if os.Getenv("ALACRITTY_WINDOW_ID") != "" {
+		log.Info("Alacritty terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
 	// Warp, tested on macOS, December 14th 2023
 	if os.Getenv("TERM_PROGRAM") == "WarpTerminal" {
+		log.Info("Warp terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
 	// GNOME Terminal, tested on Ubuntu 22.04, December 16th 2023
 	if os.Getenv("GNOME_TERMINAL_SCREEN") != "" {
+		log.Info("GNOME Terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
 	// Tilix, tested on Ubuntu 22.04, December 16th 2023
 	if os.Getenv("TILIX_ID") != "" {
+		log.Info("Tilix terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
 	// Konsole, tested on Ubuntu 22.04, December 16th 2023
 	if os.Getenv("KONSOLE_VERSION") != "" {
+		log.Info("Konsole terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
 	// Terminator, tested on Ubuntu 22.04, December 16th 2023
 	if os.Getenv("TERMINATOR_UUID") != "" {
+		log.Info("Terminator terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
@@ -309,29 +338,41 @@ func terminalHasArrowKeysEmulation() bool {
 	if os.Getenv("TERM") == "foot" || strings.HasPrefix(os.Getenv("TERM"), "foot-") {
 		// Note that this test isn't very good, somebody could be running Foot
 		// with some other TERM setting. Other suggestions welcome.
+		log.Info("Foot terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
 	// Wezterm, tested on MacOS 12.6, January 3rd, 2024
 	if os.Getenv("TERM_PROGRAM") == "WezTerm" {
+		log.Info("Wezterm terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
 	// Rio, tested on macOS 14.3, January 27th, 2024
 	if os.Getenv("TERM_PROGRAM") == "rio" {
+		log.Info("Rio terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
 	// VSCode 1.89.0, tested on macOS 14.4, May 6th, 2024
 	if os.Getenv("TERM_PROGRAM") == "vscode" {
+		log.Info("VSCode terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
 	// IntelliJ IDEA CE 2023.2.2, tested on macOS 14.4, May 6th, 2024
 	if os.Getenv("TERM_PROGRAM") == "JetBrains-JediTerm" {
+		log.Info("IntelliJ IDEA terminal detected, assuming arrow keys emulation active")
 		return true
 	}
 
+	// Ghostty 1.0.1, tested on macOS 15.1.1, Jan 12th, 2025
+	if os.Getenv("TERM_PROGRAM") == "ghostty" {
+		log.Info("Ghostty terminal detected, assuming arrow keys emulation active")
+		return true
+	}
+
+	log.Info("No known terminal with arrow keys emulation detected, assuming mouse tracking is needed")
 	return false
 }
 
@@ -373,8 +414,6 @@ func (screen *UnixScreen) ShowCursorAt(column int, row int) {
 }
 
 func (screen *UnixScreen) mainLoop() {
-	defer log.Debug("Twin screen main loop done")
-
 	// "1400" comes from me trying fling scroll operations on my MacBook
 	// trackpad and looking at the high watermark (logged below).
 	//
@@ -382,8 +421,11 @@ func (screen *UnixScreen) mainLoop() {
 	// that, so 1400 should be good.
 	buffer := make([]byte, 1400)
 
+	log.Info("Entering Twin main loop...")
+
 	maxBytesRead := 0
 	expectingTerminalBackgroundColor := true
+	var incompleteResponse []byte // To store incomplete terminal background color responses
 	for {
 		count, err := screen.ttyInReader.Read(buffer)
 		if err != nil {
@@ -391,32 +433,36 @@ func (screen *UnixScreen) mainLoop() {
 			// * https://github.com/walles/moar/issues/145
 			// * https://github.com/walles/moar/issues/149
 			// * https://github.com/walles/moar/issues/150
-			log.Debug("ttyin read error, twin giving up: ", err)
+			log.Info("ttyin read error, twin giving up: ", err)
 
 			screen.events <- EventExit{}
 			return
 		}
 
 		if expectingTerminalBackgroundColor {
+			incompleteResponse = append(incompleteResponse, buffer[:count]...)
 			// This is the response to our background color request
-			bg := parseTerminalBgColorResponse(buffer[0:count])
-			if bg != nil {
-				select {
-				case screen.events <- EventTerminalBackgroundDetected{Color: *bg}:
-					// Yay
-				default:
-					// If this happens, consider increasing the channel size in
-					// NewScreen()
-					log.Debugf("Unable to post terminal background color detected event")
+			bg, valid := parseTerminalBgColorResponse(incompleteResponse)
+			if valid {
+				if bg != nil {
+					select {
+					case screen.events <- EventTerminalBackgroundDetected{Color: *bg}:
+						// Yay
+					default:
+						// If this happens, consider increasing the channel size in
+						// NewScreen()
+						log.Debugf("Unable to post terminal background color detected event")
+					}
+					expectingTerminalBackgroundColor = false
+					incompleteResponse = nil
 				}
-				expectingTerminalBackgroundColor = false
 				continue
 			}
-		}
 
-		// We only expect this on entry, it's requested right before we start
-		// the main loop in NewScreenWithMouseModeAndColorCount().
-		expectingTerminalBackgroundColor = false
+			// Not valid, give up
+			expectingTerminalBackgroundColor = false
+			incompleteResponse = nil
+		}
 
 		if count > maxBytesRead {
 			maxBytesRead = count
@@ -542,6 +588,11 @@ func (screen *UnixScreen) Size() (width int, height int) {
 		// Resize logic needed, see below
 	default:
 		// No resize, go with the existing values
+		if screen.widthAccessFromSizeOnly == 0 || screen.heightAccessFromSizeOnly == 0 {
+			panic(fmt.Sprintf("No screen size available, this is a bug: %d x %d",
+				screen.widthAccessFromSizeOnly,
+				screen.heightAccessFromSizeOnly))
+		}
 		return screen.widthAccessFromSizeOnly, screen.heightAccessFromSizeOnly
 	}
 
@@ -551,6 +602,10 @@ func (screen *UnixScreen) Size() (width int, height int) {
 		panic(err)
 	}
 
+	if width == 0 || height == 0 {
+		panic(fmt.Sprintf("Got zero screen size: %d x %d", width, height))
+	}
+
 	if screen.widthAccessFromSizeOnly == width && screen.heightAccessFromSizeOnly == height {
 		// Not sure when this would happen, but if it does this wasn't really a
 		// resize, and we don't need to treat it as such.
@@ -578,28 +633,29 @@ func (screen *UnixScreen) RequestTerminalBackgroundColor() {
 	fmt.Println("\x1b]11;?\x07")
 }
 
-func parseTerminalBgColorResponse(responseBytes []byte) *Color {
+func parseTerminalBgColorResponse(responseBytes []byte) (*Color, bool) {
 	prefix := "\x1b]11;rgb:"
 	suffix1 := "\x07"
 	suffix2 := "\x1b\\"
 	sampleResponse1 := prefix + "0000/0000/0000" + suffix1
 	sampleResponse2 := prefix + "0000/0000/0000" + suffix2
 
-	if len(responseBytes) != len(sampleResponse1) && len(responseBytes) != len(sampleResponse2) {
-		// Not a bg color response
-		return nil
-	}
-
 	response := string(responseBytes)
 	if !strings.HasPrefix(response, prefix) {
 		log.Debug("Got unexpected prefix in bg color response from terminal: ", string(responseBytes))
-		return nil
+		return nil, false // Invalid
 	}
 	response = strings.TrimPrefix(response, prefix)
 
-	if !strings.HasSuffix(response, suffix1) && !strings.HasSuffix(response, suffix2) {
+	isComplete := strings.HasSuffix(response, suffix1) || strings.HasSuffix(response, suffix2)
+	if !isComplete && (len(responseBytes) < len(sampleResponse1) || len(responseBytes) < len(sampleResponse2)) {
+		log.Debug("Terminal bg color response received so far: ", response)
+		return nil, true // Incomplete but valid
+	}
+
+	if !isComplete {
 		log.Debug("Got unexpected suffix in bg color response from terminal: ", string(responseBytes))
-		return nil
+		return nil, false // Invalid
 	}
 	response = strings.TrimSuffix(response, suffix1)
 	response = strings.TrimSuffix(response, suffix2)
@@ -608,24 +664,24 @@ func parseTerminalBgColorResponse(responseBytes []byte) *Color {
 	red, err := strconv.ParseUint(response[0:4], 16, 16)
 	if err != nil {
 		log.Debug("Failed parsing red in bg color response from terminal: ", string(responseBytes), ": ", err)
-		return nil
+		return nil, false // Invalid
 	}
 
 	green, err := strconv.ParseUint(response[5:9], 16, 16)
 	if err != nil {
 		log.Debug("Failed parsing green in bg color response from terminal: ", string(responseBytes), ": ", err)
-		return nil
+		return nil, false // Invalid
 	}
 
 	blue, err := strconv.ParseUint(response[10:14], 16, 16)
 	if err != nil {
 		log.Debug("Failed parsing blue in bg color response from terminal: ", string(responseBytes), ": ", err)
-		return nil
+		return nil, false // Invalid
 	}
 
 	color := NewColor24Bit(uint8(red/256), uint8(green/256), uint8(blue/256))
 
-	return &color
+	return &color, true // Valid
 }
 
 func (screen *UnixScreen) SetCell(column int, row int, styledRune StyledRune) int {
